@@ -5,12 +5,12 @@ use strict;
 use Apache::Session;
 use Apache::Session::Lock::Null;
 use Apache::Session::Browseable::Store::LDAP;
-use Apache::Session::Generate::MD5;
-use Apache::Session::Serialize::Base64;
+use Apache::Session::Generate::SHA256;
+use Apache::Session::Serialize::JSON;
 use Apache::Session::Browseable::_common;
 use Net::LDAP::Util qw(escape_filter_value);
 
-our $VERSION = '1.0';
+our $VERSION = '1.3.6';
 our @ISA     = qw(Apache::Session Apache::Session::Browseable::_common);
 
 sub populate {
@@ -18,10 +18,10 @@ sub populate {
 
     $self->{object_store} = new Apache::Session::Browseable::Store::LDAP $self;
     $self->{lock_manager} = new Apache::Session::Lock::Null $self;
-    $self->{generate}     = \&Apache::Session::Generate::MD5::generate;
-    $self->{validate}     = \&Apache::Session::Generate::MD5::validate;
-    $self->{serialize}    = \&Apache::Session::Serialize::Base64::serialize;
-    $self->{unserialize}  = \&Apache::Session::Serialize::Base64::unserialize;
+    $self->{generate}     = \&Apache::Session::Generate::SHA256::generate;
+    $self->{validate}     = \&Apache::Session::Generate::SHA256::validate;
+    $self->{serialize}    = \&Apache::Session::Serialize::JSON::serialize;
+    $self->{unserialize}  = \&Apache::Session::Serialize::JSON::unserialize;
 
     return $self;
 }
@@ -29,7 +29,7 @@ sub populate {
 sub unserialize {
     my $session = shift;
     my $tmp = { serialized => $session };
-    Apache::Session::Serialize::Base64::unserialize($tmp);
+    Apache::Session::Serialize::JSON::unserialize($tmp);
     return $tmp->{data};
 }
 
@@ -64,25 +64,35 @@ sub searchOnExpr {
 
 sub _query {
     my ( $class, $args, $selectField, $value, @fields ) = @_;
+    $args->{ldapObjectClass}      ||= 'applicationProcess';
+    $args->{ldapAttributeId}      ||= 'cn';
+    $args->{ldapAttributeContent} ||= 'description';
+    $args->{ldapAttributeIndex}   ||= 'ou';
 
     my %res = ();
     my $ldap =
       Apache::Session::Browseable::Store::LDAP::ldap( { args => $args } );
     my $msg = $ldap->search(
-        base => $args->{ldapConfBase},
-        filter =>
-          "(&(objectClass=applicationProcess)(ou=${selectField}_$value))",
+        base   => $args->{ldapConfBase},
+        filter => "(&(objectClass="
+          . $args->{ldapObjectClass} . ")("
+          . $args->{ldapAttributeIndex}
+          . "=${selectField}_$value))",
 
         #scope => 'base',
-        attrs => [ 'description', 'cn' ],
+        attrs => [ $args->{ldapAttributeContent}, $args->{ldapAttributeId} ],
     );
+
+    $ldap->unbind();
+    $ldap->disconnect();
+
     if ( $msg->code ) {
         Apache::Session::Browseable::Store::LDAP->logError($msg);
     }
     else {
         foreach my $entry ( $msg->entries ) {
-            my $id = $entry->get_value('cn') or die;
-            my $tmp = $entry->get_value('description');
+            my $id = $entry->get_value( $args->{ldapAttributeId} ) or die;
+            my $tmp = $entry->get_value( $args->{ldapAttributeContent} );
             next unless ($tmp);
             eval { $tmp = unserialize($tmp); };
             next if ($@);
@@ -101,6 +111,11 @@ sub get_key_from_all_sessions {
     my $class = shift;
     my $args  = shift;
     my $data  = shift;
+    $args->{ldapObjectClass}      ||= 'applicationProcess';
+    $args->{ldapAttributeId}      ||= 'cn';
+    $args->{ldapAttributeContent} ||= 'description';
+    $args->{ldapAttributeIndex}   ||= 'ou';
+
     my %res;
 
     my $ldap =
@@ -110,16 +125,22 @@ sub get_key_from_all_sessions {
 
      # VERY STRANGE BUG ! With this filter, description isn't base64 encoded !!!
      #filter => '(objectClass=applicationProcess)',
-        filter => '(&(objectClass=applicationProcess)(ou=*))',
-        attrs  => [ 'cn', 'description' ],
+
+        filter => '(&(objectClass='
+          . $args->{ldapObjectClass} . ')('
+          . $args->{ldapAttributeIndex} . '=*))',
+        attrs => [ $args->{ldapAttributeId}, $args->{ldapAttributeContent} ],
     );
+
+    $ldap->unbind();
+
     if ( $msg->code ) {
         Apache::Session::Browseable::Store::LDAP->logError($msg);
     }
     else {
         foreach my $entry ( $msg->entries ) {
-            my $id = $entry->get_value('cn') or die;
-            my $tmp = $entry->get_value('description');
+            my $id = $entry->get_value( $args->{ldapAttributeId} ) or die;
+            my $tmp = $entry->get_value( $args->{ldapAttributeContent} );
             next unless ($tmp);
             eval { $tmp = unserialize($tmp); };
             next if ($@);
@@ -151,11 +172,17 @@ Apache::Session::Browseable::LDAP - An implementation of Apache::Session::LDAP
 
   use Apache::Session::Browseable::LDAP;
   tie %hash, 'Apache::Session::Browseable::LDAP', $id, {
-    ldapServer       => 'ldap://localhost:389',
-    ldapConfBase     => 'dmdName=applications,dc=example,dc=com',
-    ldapBindDN       => 'cn=admin,dc=example,dc=com',
-    ldapBindPassword => 'pass',
-    Index            => 'uid ipAddr',
+    ldapServer           => 'ldap://localhost:389',
+    ldapConfBase         => 'dmdName=applications,dc=example,dc=com',
+    ldapBindDN           => 'cn=admin,dc=example,dc=com',
+    ldapBindPassword     => 'pass',
+    Index                => 'uid ipAddr',
+    ldapObjectClass      => 'applicationProcess',
+    ldapAttributeId      => 'cn',
+    ldapAttributeContent => 'description',
+    ldapAttributeIndex   => 'ou',
+    ldapVerify           => 'require',
+    ldapCAFile           => '/etc/ssl/certs/ca-certificates.crt',
   };
 
 =head1 DESCRIPTION
@@ -163,16 +190,23 @@ Apache::Session::Browseable::LDAP - An implementation of Apache::Session::LDAP
 This module is an implementation of Apache::Session. It uses an LDAP directory
 to store datas.
 
-=head1 AUTHOR
-
-Xavier Guimard, E<lt>x.guimard@free.frE<gt>
-
 =head1 COPYRIGHT AND LICENSE
 
 =encoding utf8
 
-Copyright (C) 2009 by Xavier Guimard
-              2013 by Clément Oudot
+=over
+
+=item 2009-2023 by Xavier Guimard
+
+=item 2013-2023 by Clément Oudot
+
+=item 2019-2023 by Maxime Besson
+
+=item 2013-2023 by Worteks
+
+=item 2023 by Linagora
+
+=back
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.10.0 or,
