@@ -9,7 +9,7 @@ use Apache::Session::Generate::SHA256;
 use Apache::Session::Serialize::JSON;
 use Apache::Session::Browseable::DBI;
 
-our $VERSION = '1.2.2';
+our $VERSION = '1.2.5';
 our @ISA     = qw(Apache::Session::Browseable::DBI Apache::Session);
 
 sub populate {
@@ -25,8 +25,13 @@ sub populate {
     return $self;
 }
 
-1;
+# Override default CAST syntax from DBI.pm
+sub _buildLowerThanExpression {
+    my ( $class, $field, $value ) = @_;
+    return "CAST($field AS SIGNED INTEGER) < $value";
+}
 
+1;
 __END__
 
 =head1 NAME
@@ -36,6 +41,26 @@ Apache::Session::MySQL
 
 =head1 SYNOPSIS
 
+Create table with columns for indexed fields. Example for Lemonldap::NG:
+
+  CREATE TABLE sessions (
+      id varchar(64) not null primary key,
+      a_session text,
+      _whatToTrace text,
+      _session_kind text,
+      _utime bigint,
+      ipAddr text
+  );
+
+Add indexes:
+
+  CREATE INDEX uid1 ON sessions (_whatToTrace) USING BTREE;
+  CREATE INDEX s1   ON sessions (_session_kind);
+  CREATE INDEX u1   ON sessions (_utime);
+  CREATE INDEX ip1  ON sessions (ipAddr) USING BTREE;
+
+Use it with Perl:
+
   use Apache::Session::Browseable::MySQL;
 
   my $args = {
@@ -96,16 +121,23 @@ sessions and add the capability to index some fields to make research faster.
 
 L<Apache::Session>
 
-=head1 AUTHOR
-
-Xavier Guimard, E<lt>x.guimard@free.frE<gt>
-
 =head1 COPYRIGHT AND LICENSE
 
 =encoding utf8
 
-Copyright (C) 2009-2013 by Xavier Guimard
-              2013 by Clément Oudot
+=over
+
+=item 2009-2023 by Xavier Guimard
+
+=item 2013-2023 by Clément Oudot
+
+=item 2019-2023 by Maxime Besson
+
+=item 2013-2023 by Worteks
+
+=item 2023 by Linagora
+
+=back
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.10.1 or,
