@@ -9,7 +9,7 @@ use Apache::Session::Lock::Null;
 use Apache::Session::Serialize::JSON;
 use Apache::Session::Browseable::_common;
 
-our $VERSION = '1.3.5';
+our $VERSION = '1.3.9';
 our @ISA     = qw(Apache::Session);
 
 our $redis = $Apache::Session::Browseable::Store::Redis::redis;
@@ -97,6 +97,7 @@ sub get_key_from_all_sessions {
         next if ( !$k or $k =~ /_/ );
         eval {
             my $v   = $redisObj->get($k);
+            next unless $v;
             my $tmp = unserialize($v);
             if ( ref($data) eq 'CODE' ) {
                 $tmp = &$data( $tmp, $k );
@@ -162,7 +163,7 @@ Apache::Session::Redis
        # Select database (optional)
        #database => 0,
 
-       # Choose your browseable fileds
+       # Choose your browseable fields
        Index          => 'uid mail',
   };
   
@@ -215,13 +216,21 @@ This module use either L<Redis::Fast> or L<Redis>.
 
 L<Apache::Session>
 
-=head1 AUTHOR
-
-Xavier Guimard, E<lt>x.guimard@free.frE<gt>
-
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2018 by Xavier Guimard
+=over
+
+=item 2009-2023 by Xavier Guimard
+
+=item 2013-2023 by Clément Oudot
+
+=item 2019-2023 by Maxime Besson
+
+=item 2013-2023 by Worteks
+
+=item 2023 by Linagora
+
+=back
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.10.1 or,
